==> check-mk_1.2.6p5.orig.tar.gz: src/AttributelistFilter.h <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#ifndef AttributelistFilter_h
#define AttributelistFilter_h

#include "config.h"
#include "Filter.h"
#include <stdlib.h>

class AttributelistColumn;

class AttributelistFilter : public Filter
{
    AttributelistColumn *_column;
    int _opid;
    bool _negate;
    unsigned long _ref;

public:
    AttributelistFilter(AttributelistColumn *column, int opid, unsigned long ref) :
        _column(column), _opid(abs(opid)), _negate(opid < 0), _ref(ref) {}
    bool accepts(void *data);
};


#endif // AttributelistFilter_h

==> check-mk_1.2.8p16.orig.tar.gz: src/AttributelistFilter.h <==
// +------------------------------------------------------------------+
// |             ____ _               _        __  __ _  __           |
// |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
// |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
// |           | |___| | | |  __/ (__|   <    | |  | | . \            |
// |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
// |                                                                  |
// | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
// +------------------------------------------------------------------+
//
// This file is part of Check_MK.
// The official homepage is at http://mathias-kettner.de/check_mk.
//
// check_mk is free software;  you can redistribute it and/or modify it
// under the  terms of the  GNU General Public License  as published by
// the Free Software Foundation in version 2.  check_mk is  distributed
// in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
// out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
// PARTICULAR PURPOSE. See the  GNU General Public License for more de-
// ails.  You should have  received  a copy of the  GNU  General Public
// License along with GNU Make; see the file  COPYING.  If  not,  write
// to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
// Boston, MA 02110-1301 USA.

#ifndef AttributelistFilter_h
#define AttributelistFilter_h

#include "config.h"  // IWYU pragma: keep
#include <stdlib.h>
#include "Filter.h"
class AttributelistColumn;

class AttributelistFilter : public Filter {
    AttributelistColumn *_column;
    int _opid;
    bool _negate;
    unsigned long _ref;

public:
    AttributelistFilter(AttributelistColumn *column, int opid,
                        unsigned long ref)
        : _column(column), _opid(abs(opid)), _negate(opid < 0), _ref(ref) {}
    bool accepts(void *data);
};

#endif  // AttributelistFilter_h
